@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1604';
+our $VERSION = '0.1605';
 
 use Math::Bezier;
 use MIDI::Simple;
@@ -266,8 +266,7 @@ sub metronome78 {
         $self->note($self->eighth, $self->closed_hh, $self->kick);
         $self->note($self->eighth, $self->closed_hh);
         $self->note($self->eighth, $self->closed_hh);
-        $self->note($self->sixteenth, $self->closed_hh, $self->kick);
-        $self->note($self->sixteenth, $self->kick);
+        $self->note($self->eighth, $self->closed_hh, $self->kick);
         $self->note($self->eighth, $self->closed_hh, $self->snare);
         $self->note($self->eighth, $self->closed_hh);
         $self->note($self->eighth, $self->closed_hh);
@@ -277,6 +276,7 @@ sub metronome78 {
 
 sub flam {
     my ($self, $spec, $patch) = @_;
+    $patch ||= $self->snare;
     my $x = $MIDI::Simple::Length{$spec};
     my $y = $MIDI::Simple::Length{ $self->sixtyfourth };
     my $z = sprintf '%0.f', ($x - $y) * TICKS;
@@ -372,7 +372,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1604
+version 0.1605
 
 =head1 SYNOPSIS
 
@@ -611,13 +611,17 @@ Add a 7/8 beat to the score.
 
 =head2 flam
 
+  $d->flam($spec);
   $d->flam( $spec, $patch );
 
-Add a flam to the score, where a ghosted gracenote is played before
-the primary note.
+Add a "flam" to the score, where a ghosted 64th gracenote is played
+before the primary note.
+
+If not provided the B<snare> is used for the B<patch>.
 
 =head2 roll
 
+  $d->roll( $length, $spec );
   $d->roll( $length, $spec, $patch );
 
 Add a drum roll to the score, where the B<patch> is played for
@@ -627,6 +631,7 @@ If not provided the B<snare> is used for the B<patch>.
 
 =head2 crescendo_roll
 
+  $d->crescendo_roll( [$start, $end, $bezier], $length, $spec );
   $d->crescendo_roll( [$start, $end, $bezier], $length, $spec, $patch );
 
 Add a drum roll to the score, where the B<patch> is played for
@@ -655,19 +660,21 @@ C<time_signature> values based on the given string.
 
 =head2 write
 
-Output the score to the default F<*.mid> file or one given to the
-constuctor.
+Output the score as a MIDI file with the module L</file> setting as
+the file name.
 
 =head1 SEE ALSO
 
-The F<eg/*> programs in this distribution and
-F<eg/drum-fills-advanced> in the L<Music::Duration::Partition>
-distribution
+The metronome method sources in this module, the F<eg/*> programs in
+this distribution, and also F<eg/drum-fills-advanced> in the
+L<Music::Duration::Partition> distribution
 
-L<Moo>
+L<Math::Bezier>
 
 L<MIDI::Simple>
 
+L<Moo>
+
 L<Music::Duration>
 
 L<https://en.wikipedia.org/wiki/General_MIDI#Percussion>
